@@ -1,11 +1,12 @@
 import numpy as np
 
+
 class CompassSensorMixin:
 
-    device_type = 'lego-sensor'
+    device_type = "lego-sensor"
 
     relative = 0
-    mode = 'COMPASS'
+    mode = "COMPASS"
 
     def _setRelative(self):
         self.relative = self.global_rotation
@@ -19,26 +20,26 @@ class CompassSensorMixin:
         return r
 
     def _getObjName(self, port):
-        return 'sensor' + port
+        return "sensor" + port
 
     def applyWrite(self, attribute, value):
-        if attribute == 'mode':
+        if attribute == "mode":
             self.mode = value
-        elif attribute == 'command':
-            if value == 'BEGIN-CAL':
+        elif attribute == "command":
+            if value == "BEGIN-CAL":
                 self._setRelative()
-            elif value == 'END-CAL':
+            elif value == "END-CAL":
                 pass
             else:
-                raise ValueError(f'Unknown compass command {value}')
+                raise ValueError(f"Unknown compass command {value}")
         else:
-            raise ValueError(f'Unhandled write! {attribute} {value}')
+            raise ValueError(f"Unhandled write! {attribute} {value}")
 
     def toObject(self):
         return {
-            'address': self._interactor.port,
-            'driver_name': 'ht-nxt-compass',
-            'mode': self.mode,
-            'value0': self.value(),
-            'decimals': 0,
+            "address": self._interactor.port,
+            "driver_name": "ht-nxt-compass",
+            "mode": self.mode,
+            "value0": self.value(),
+            "decimals": 0,
         }
