@@ -1,60 +1,66 @@
+from queue import Queue
 from ev3sim.simulation.interactor import IInteractor
 from ev3sim.simulation.loader import ScriptLoader
 from ev3sim.simulation.world import stop_on_pause
 
+
 def add_devices(parent, device_info):
     devices = []
     for info in device_info:
         key = list(info.keys())[0]
-        devices.append({"name":key})
+        devices.append({"name": key})
         devices[-1].update(info[key])
         devices[-1]["type"] = "device"
     parent["children"] = parent.get("children", []) + devices
 
+
 def add_to_key(obj, prefix):
     if isinstance(obj, dict):
-        if 'key' in obj:
-            obj['key'] = prefix + obj['key']
+        if "key" in obj:
+            obj["key"] = prefix + obj["key"]
         for value in obj.values():
             add_to_key(value, prefix)
     if isinstance(obj, (list, tuple)):
         for v in obj:
             add_to_key(v, prefix)
 
+
 def initialise_bot(topLevelConfig, filename, prefix):
     # Returns the robot class, as well as a completed robot to add to the elements list.
     import yaml
-    with open(filename, 'r') as f:
+
+    with open(filename, "r") as f:
         try:
             config = yaml.safe_load(f)
-            mname, cname = config.get('robot_class', 'ev3sim.robot.Robot').rsplit('.', 1)
+            mname, cname = config.get("robot_class", "ev3sim.robot.Robot").rsplit(".", 1)
             import importlib
+
             klass = getattr(importlib.import_module(mname), cname)
-            bot_config = config['base_plate']
-            bot_config['type'] = 'object'
-            bot_config['physics'] = True
-            add_devices(bot_config, config.get('devices', []))
+            bot_config = config["base_plate"]
+            bot_config["type"] = "object"
+            bot_config["physics"] = True
+            add_devices(bot_config, config.get("devices", []))
             add_to_key(bot_config, prefix)
             # Append bot object to elements.
-            topLevelConfig['elements'] = topLevelConfig.get('elements', []) + [bot_config]
+            topLevelConfig["elements"] = topLevelConfig.get("elements", []) + [bot_config]
             robot = klass()
-            ScriptLoader.instance.active_scripts.append(RobotInteractor(**{
-                'robot': robot,
-                'base_key': bot_config['key']
-            }))
+            ScriptLoader.instance.active_scripts.append(
+                RobotInteractor(**{"robot": robot, "base_key": bot_config["key"]})
+            )
             robot.ID = prefix
             ScriptLoader.instance.robots[prefix] = robot
+            ScriptLoader.instance.data["events"][robot.ID] = Queue()
         except yaml.YAMLError as exc:
-            print(f"An error occured while loading robot preset {filename}. Exited with error: {exc}")
+            print(f"An error occurred while loading robot preset {filename}. Exited with error: {exc}")
+
 
 class RobotInteractor(IInteractor):
-
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
-        self.robot_class : Robot = kwargs.get('robot')
+        self.robot_class: Robot = kwargs.get("robot")
         self.robot_class._interactor = self
-        self.robot_key = kwargs.get('base_key')
-    
+        self.robot_key = kwargs.get("base_key")
+
     def connectDevices(self):
         self.devices = {}
         for interactor in ScriptLoader.instance.object_map[self.robot_key].device_interactors:
@@ -72,7 +78,7 @@ class RobotInteractor(IInteractor):
     def tick(self, tick):
         self.robot_class.tick(tick)
         return False
-    
+
     def handleEvent(self, event):
         self.robot_class.handleEvent(event)
 
@@ -84,6 +90,7 @@ class RobotInteractor(IInteractor):
             res[device.device_type][device._getObjName(port)] = device.toObject()
         return res
 
+
 class Robot:
     """
     A robot is as you'd expect in the physical sense - a collection of devices on a base board,
@@ -99,7 +106,7 @@ class Robot:
     def getDevice(self, port):
         """
         Returns an instance of the device on the port specified.
-        
+
         :param string port: The port of the device to retrieve.
 
         Example usage:
@@ -123,7 +130,7 @@ class Robot:
         Override with code to be executed whenever the robot is instantiated.
         """
         pass
-    
+
     def onSpawn(self):
         """
         Since soccer and possibly other games require the placement and rotation of bots, a method separate to ``startUp``
@@ -150,4 +157,4 @@ class Robot:
 
         Shouldn't be required for normal bots.
         """
-        pass
\ No newline at end of file
+        pass
